==> json-diff-0.9.1.tgz: json-diff/README.md <==
# Installation
> `npm install --save @types/json-diff`

# Summary
This package contains type definitions for json-diff (https://github.com/andreyvit/json-diff).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/json-diff.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/json-diff/index.d.ts)
````ts
// Type definitions for json-diff 0.9
// Project: https://github.com/andreyvit/json-diff
// Definitions by: Tommy Wong <https://github.com/wchtommy20013/>
//                 Jerryh001 <https://github.com/Jerryh001>
//                 HoldYourWaffle <https://github.com/HoldYourWaffle>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

export interface DiffOptions {
    verbose?: boolean;
    raw?: boolean;
    keysOnly?: boolean;
    full?: boolean;
    sort?: boolean;
    outputKeys?: string[];
    keepUnchangedValues?: boolean;
    outputNewOnly?: boolean;
    maxElisions?: number;
    precision?: number;
}

export interface DiffStringOptions extends DiffOptions {
    color?: boolean;
}

export function diff(obj1: unknown, obj2: unknown, options?: DiffOptions): any;
export function diffString(obj1: unknown, obj2: unknown, options?: DiffStringOptions): string;

````

### Additional Details
 * Last updated: Mon, 14 Nov 2022 17:03:04 GMT
 * Dependencies: none
 * Global values: none

# Credits
These definitions were written by [Tommy Wong](https://github.com/wchtommy20013), [Jerryh001](https://github.com/Jerryh001), and [HoldYourWaffle](https://github.com/HoldYourWaffle).

==> json-diff-1.0.0.tgz: json-diff/README.md <==
# Installation
> `npm install --save @types/json-diff`

# Summary
This package contains type definitions for json-diff (https://github.com/andreyvit/json-diff).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/json-diff.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/json-diff/index.d.ts)
````ts
// Type definitions for json-diff 1.0
// Project: https://github.com/andreyvit/json-diff
// Definitions by: Tommy Wong <https://github.com/wchtommy20013/>
//                 Jerryh001 <https://github.com/Jerryh001>
//                 HoldYourWaffle <https://github.com/HoldYourWaffle>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

export interface DiffOptions {
    verbose?: boolean;
    raw?: boolean;
    keysOnly?: boolean;
    full?: boolean;
    sort?: boolean;
    outputKeys?: string[];
    excludeKeys?: string[];
    keepUnchangedValues?: boolean;
    outputNewOnly?: boolean;
    maxElisions?: number;
    precision?: number;
}

export interface DiffStringOptions extends DiffOptions {
    color?: boolean;
}

export function diff(obj1: unknown, obj2: unknown, options?: DiffOptions): any;
export function diffString(obj1: unknown, obj2: unknown, options?: DiffStringOptions): string;

````

### Additional Details
 * Last updated: Tue, 30 May 2023 17:33:09 GMT
 * Dependencies: none
 * Global values: none

# Credits
These definitions were written by [Tommy Wong](https://github.com/wchtommy20013), [Jerryh001](https://github.com/Jerryh001), and [HoldYourWaffle](https://github.com/HoldYourWaffle).
